package de.intevation.flys.backend;

import org.apache.log4j.Logger;

import org.hibernate.Session;
import org.hibernate.SessionFactory;


public class SessionHolder
{
    private static Logger log =
        Logger.getLogger(SessionHolder.class);

    public static final ThreadLocal<Session> HOLDER =
        new ThreadLocal<Session>() {
            @Override
            protected Session initialValue() {
                return create();
            }
        };

    private SessionHolder() {
    }

    public synchronized static Session create() {
        log.debug("create");
        SessionFactory sessionFactory =
            SessionFactoryProvider.getSessionFactory();
        return sessionFactory.openSession();
    }

    public static Session acquire() {
        log.debug("acquire");
        Session session = create();
        HOLDER.set(session);
        return session;
    }

    public static void release() {
        log.debug("release");
        HOLDER.remove();
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
